@@ -3,6 +3,8 @@
 # Distributed under the Boost Software License, Version 1.0.
 # See http://www.boost.org/LICENSE_1_0.txt
 
+import platform
+
 from . import autoconfig
 
 from pygccxml import parser
@@ -22,7 +24,12 @@ def test_map_gcc5():
     """
 
     config = autoconfig.cxx_parsers_cfg.config.clone()
-    config.cflags = "-std=c++11"
+    if platform.system() == "Darwin":
+        config.cflags = "-std=c++11 -Dat_quick_exit=atexit -Dquick_exit=exit"
+        # https://fr.mathworks.com/matlabcentral/answers/2013982-clibgen-generatelibrarydefinition-error-the-global-scope-has-no-quick_exit-on-mac-m2#answer_1439856
+        # https://github.com/jetbrains/kotlin/commit/d50f585911dedec5723213da8835707ac95e1c01
+    else:
+        config.cflags = "-std=c++11"
 
     decls = parser.parse(TEST_FILES, config)
     global_ns = declarations.get_global_namespace(decls)
